==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/help.php <==
<?php /* Copyright (C) 2006, 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}

$sovix__file_is_topic="n";
$sovix__width="100%";
require_once "$sovix__directory__src/header.inc";

$sovix__print=$_GET['print'];
$sovix__input=$_GET['input'];
$sovix__subtask=$_POST['sovix__subtask'];
$sovix__task=$_GET['task'];
$sovix__3=$_GET['sovix__3'];
$sovix__2=$_GET['sovix__2'];
if (strpos($sovix__2, "/..")  !== false && isset($_SESSION['sovix__user'])) unset ($sovix__2); # So the public cant access any file. We could have used PHPs realpath also

$sovix__pieces = explode("/", dirname($sovix__2));
$sovix__select_menu__index=$sovix__pieces[sizeof($sovix__pieces) - 1];

# $sovix__fig dir is different in toolbar.inc
$sovix__fig_dir=$sovix__2;
require "$sovix__directory__src/read-fig.inc";
require "$sovix__directory__src/read-default.inc";

if (strpos($sovix__2, "/private/") !==false && $_SESSION['sovix__user']!="root") {
  echo "Only root is allowed to access files in &ldquo;private&rdquo; directories."; # auth_sovix.inc.php could be readed from other websites using Sovix otherwise.
 }
elseif (
    $sovix__task=="open-file" ||
    $sovix__task=="visit-new-file" &&
    $_SESSION['sovix__user']=="root" /* Any file must be able to open, including special directories and Sovix files. Open File... and Visit New File... is the same thing in Emacs */ ) {

  if (isset($_SESSION['sovix__user']) || $sovix__2=="$sovix__directory__sovix/Public_sandbox.inc" || $sovix__2=="$sovix__directory__sovix"."Public_sandbox.inc") {
    if (is_file($sovix__2) && $sovix__task=="visit-new-file") echo "File exist allready.";
    else {

    $sovix__script = $_POST['sovix__script']; $_SESSION['sovix__script']=$sovix__script;

					       if ($sovix__subtask=="writefile") {
						 /*  if (is_writable($sovix__2)) {  This is useless if we want to be able to insert a new file */
						 if($sovix__2&&$sovix__script) {
						   $sovix__foo=stripslashes($sovix__script);
						   $sovix__fp=fopen($sovix__2, "w+");
						   fwrite($sovix__fp,$sovix__foo);
						   fclose($sovix__fp);
						   echo "
<p>Wrote $sovix__2 &nbsp;
[ <a href=\"".str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2")."\">";
echo str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2");
echo "</a> ]
</p>";
						 }
					       }
      ?>
				  <form action="" method="post" />
				     <input type="hidden" name="sovix__input" value="open-file <?php echo $sovix__2 ?>" />
				     <input type="hidden" name="sovix__subtask" value="writefile" />
				     <textarea rows="30" name="sovix__script"><?php
				     if ($sovix__task=="open-file" && file_exists("$sovix__2")) echo htmlspecialchars(file_get_contents("$sovix__2"));
				     /*
                                       if (is_file($sovix__2)) {
					 $sovix__fp=fopen($sovix__2,"r");
					 $sovix__t="";
					 while(!feof($sovix__fp)) {
					   $sovix__t.=fread($sovix__fp,1024);
					 }
					 fclose($sovix__fp);
					 print htmlspecialchars($sovix__t);
				       }
                                     */
                                     ?></textarea>
					       <p></p>
					       <input type="submit" value="<?php
if ($sovix__task=="open-file" && file_exists("$sovix__2")) echo "Write  file";
elseif (!file_exists("$sovix__2")) echo "Insert file";
elseif ($sovix__task=="visit-new-file") echo "Insert file"; ?>" /><p></p>
					       Whitespace and line breaks may differ when writing to the<br />
					       file with one or 2 bytes so the MD5sum is likley to be changed even if no visible changes is being made..
					       </form>
					       <?php

    }
  }
  else echo "You are not logged in";
 }

elseif ($sovix__task=="extensions") {
  if (file_exists("$sovix__url__sovix/diet/")) echo "Sovix Diet is installed: [<a href=\"http://sovix.org/extensions/sovix-diet\">Find updates</a>]";
  else echo "No extensions is currently installed. <a href=\"http://sovix.org/extensions/\">Get more extensions</a>";
}

elseif ($sovix__task=="wikiinsert" && str_replace("$sovix__directory__document_root", "", dirname($sovix__2))=="/Main") {
  echo "<p><h2>wiki</h2>";

    if (!is_file($sovix__2)) echo "No such file. Begin with / to indicate DocumentRoot., press submit to write it.";
    if (is_file($sovix__2)) echo "File exist allready.";
    else {

    $sovix__script = $_POST['sovix__script']; $_SESSION['sovix__script']=$sovix__script;
      ?>
				  <form action="" method="post" />
				     <input type="hidden" name="sovix__input" value="open-file <?php echo $sovix__2 ?>" />
				     <input type="hidden" name="sovix__subtask" value="writefile" />
				     <textarea rows="30" name="sovix__script"></textarea>
					       <p></p>
					       <input type="submit" value="<?php if ($sovix__task=="wikiopen") echo "Modify file"; elseif ($sovix__task=="wikiinsert") echo "Insert file"; ?>" /><p></p>
					       Whitespace and line breaks may differ when writing to the<br />
					       file with one or 2 bytes so the MD5sum is likley to be changed.
					       </form>
					       <?php
					       if ($sovix__subtask=="writefile") {
						 if($sovix__2&&$sovix__script) {
						   $sovix__foo=htmlentities($sovix__script);
                                                   $sovix__zop="<?php \$sovix__directory__src=\$_SERVER\['DOCUMENT_ROOT'\].\"/sovix\"; \$sovix__directory__dotsovix=\"\$sovix__directory__src/../dotsovix/\"; require_once \"\$sovix__directory__src/header.inc\"; ?><pre>".$sovix__script."
</pre>

<?php require_once \"\$sovix__directory__src/footer.inc\"; ?>";
						   $sovix__fp=fopen($sovix__2, "w+");
						   fwrite($sovix__fp,$sovix__zop);
						   fclose($sovix__fp);
						   echo "
<p>Wrote $sovix__2 &nbsp;
[ <a href=\"".str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2")."\">";
echo str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2");
echo "</a> ]
</p>";
						 }
					       }

    }

}

elseif ($sovix__task=="html-entities") {

$sovix__i=1;
while ($sovix__i <= 8205):
  echo "&#"; echo "$sovix__i = &#38;&#35;$sovix__i&#59;"; echo "<br />\n";
$sovix__i++;
endwhile;
}

elseif ($sovix__task=="copy-file") {
  if ($_SESSION['sovix__user']=="root") {
    if (!copy("$sovix__2", "$sovix__3")) {
  echo "failed to copy $file...\n";
 }
    else echo "You are not logged in";
  }
}

elseif ($sovix__task=="read-file") {  ?>
  <?php
    if ($_SESSION['sovix__user']=="root" || ($sovix__file__read_file_ok==true || $sovix__allow_read_for_sovix_files==true)) {
      if (substr("$sovix__2", 0, 7)!="http://") {
	if (is_file($sovix__2)) highlight_file($sovix__2);
	else echo "No such file. Begin with / to indicate DocumentRoot.";
      }
      else echo "Define a file, not a URL. Begin with / to indicate DocumentRoot.";
    }
}
elseif ($sovix__task=="read-file-textarea") {
  if ($_SESSION['sovix__user']=="root" || ($sovix__file__read_file_ok==true || $sovix__allow_read_for_sovix_files==true)) {
    if (substr("$sovix__2", 0, 7)!="http://") {
      if (is_file($sovix__2)) {
	if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; }
  ?>
 <textarea rows="30" name="sovix__script"><?php
    if (is_file($sovix__2)) {
      echo htmlspecialchars(file_get_contents("$sovix__2"));
    }
   ?></textarea>
	<?php
	 }
      else echo "No such file. Begin with / to indicate DocumentRoot.";
    }
    elseif (substr("$sovix__2", 0, 7)=="http://")  {
      if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; } ?>
 <textarea rows="30" name="sovix__script"><?php
      echo htmlspecialchars(file_get_contents("$sovix__2"));
   ?></textarea>
	<?php
	}
  }
}
elseif ($sovix__task=="read-file-pre") {
  if ($_SESSION['sovix__user']=="root" || ($sovix__file__read_file_ok==true || $sovix__allow_read_for_sovix_files==true)) {
    if (substr("$sovix__2", 0, 7)!="http://") {
      if (is_file($sovix__2)) {
	if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; }
  ?>
 <pre><?php
    if (is_file($sovix__2)) {
      echo htmlspecialchars(file_get_contents("$sovix__2"));
    }
   ?></pre>
	<?php
	 }
      else echo "No such file. Begin with / to indicate DocumentRoot.";
    }
    elseif (substr("$sovix__2", 0, 7)=="http://")  {
      if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; } ?>
 <pre><?php
      echo htmlspecialchars(file_get_contents("$sovix__2"));
   ?></pre>
	<?php
	}
  }
}
elseif ($sovix__task=="read-pagesource") {

	 if (!is_file($sovix__2)) {
	   if (!isset($sovix__format)) { echo "<p><h2>Page source of: $sovix__2</h2></p>"; }
	   highlight_file($sovix__2);
	 }

}
elseif ($sovix__task=="file-get-contents") {
  if (isset($_SESSION['sovix__user'])) {
  if (substr("$sovix__2", 0, 7)!="http://") echo "Requested URL must begin with http://";
  else {
   echo "<p><h2>Getting contents from: ".$sovix__2."</h2></p>";
   echo file_get_contents("$sovix__2"); }
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="file-require") {
  if (isset($_SESSION['sovix__user'])) {
  if ($sovix__select_menu__index!="secret") {
    if (is_file($sovix__2)) {
   echo "<p><h2>Framing: ".$sovix__2."</h2></p>";
require_once $sovix__2;
    }
    else echo "No such file. Begin with / to indicate DocumentRoot..";
  }
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="delete-file") {
  if ($_SESSION['sovix__user']=="root") {
    if (is_file($sovix__2)) {unlink($sovix__2); echo "File $sovix__2 has been deleted.";}
    else "No such file. Begin with / to indicate DocumentRoot..";
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="make-directory") {
  if ($_SESSION['sovix__user']=="root") {
    mkdir($sovix__2); echo "Directory $sovix__2 has been made.";
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="delete-directory") {
  if ($_SESSION['sovix__user']=="root") {
    if(is_dir($sovix__2)) {rmdir($sovix__2); echo "Directory $sovix__2 has been deleted.";}
    else "No such directory.";
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="rename-file") {
  if ($_SESSION['sovix__user']=="root") {
  echo "$sovix__2 $sovix__3";
rename("$sovix__2", "$sovix__3");
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="identify") { ?>
 <?php
     if (file_exists($sovix__2)) { /* could be a directory so do not use if_file */
   echo "<p><h2>Identify: ".$sovix__2."</h2></p>";
       echo "
Filename: ".basename($sovix__2)."<br />
File path: ".dirname($sovix__2)."<br />
File extension: ". substr($sovix__2,strrpos($sovix__2,'.') + 0)."<br />
Number of lines: ".count(file("$sovix__2"))."<br />
md5 hash: ".md5_file($sovix__2)."<br />
Last access time of file: ".date ("Y-m-d H:i:s", fileatime($sovix__2))."<br />
Inode change time of file: ".date ("Y-m-d H:i:s", filectime($sovix__2))."<br />
File group: ".filegroup($sovix__2)."<br />
File inode: ".fileinode($sovix__2)."<br />
File modification time: ".date ("Y-m-d H:i:s", filemtime($sovix__2))."<br />
File owner: ".fileowner($sovix__2)."<br />
File permissions: ".fileperms($sovix__2)."<br />
File size: ".filesize($sovix__2)."<br />
File type: ".filetype($sovix__2)."<br />
";
     }
     else echo "No such file. Begin with / to indicate DocumentRoot..";
}
elseif (empty($sovix__task)) {
  echo "No command name given<p></p>";
}
else {
  echo "[No match]<p></p>";
}
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6.tar.gz: sovix-0.0.1.6/websrc/help.php <==
<?php /* Copyright (C) 2006, 2007, 2008 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007, 2008 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}

$sovix__file_is_topic="n";
$sovix__width="100%";
require_once "$sovix__directory__src/header.inc";

$sovix__print=$_GET['print'];
$sovix__input=$_GET['input'];
$sovix__subtask=$_POST['sovix__subtask'];
$sovix__task=$_GET['task'];
$sovix__3=$_GET['sovix__3'];
$sovix__2=$_GET['sovix__2'];
if (strpos($sovix__2, "/..")  !== false && isset($_SESSION['sovix__user'])) unset ($sovix__2); # So the public cant access any file. We could have used PHPs realpath also

$sovix__pieces = explode("/", dirname($sovix__2));
$sovix__select_menu__index=$sovix__pieces[sizeof($sovix__pieces) - 1];

# $sovix__fig dir is different in toolbar.inc
$sovix__fig_dir=$sovix__2;
require "$sovix__directory__src/read-fig.inc";
require "$sovix__directory__src/read-default.inc";

if (strpos($sovix__2, "/private/") !==false && $_SESSION['sovix__user']!="root") {
  echo "Only root is allowed to access files in &ldquo;private&rdquo; directories."; # auth_sovix.inc.php could be readed from other websites using Sovix otherwise.
 }
elseif (
    $sovix__task=="open-file" ||
    $sovix__task=="visit-new-file" &&
    $_SESSION['sovix__user']=="root" /* Any file must be able to open, including special directories and Sovix files. Open File... and Visit New File... is the same thing in Emacs */ ) {

  if (isset($_SESSION['sovix__user']) || $sovix__2=="$sovix__directory__sovix/Public_sandbox.inc" || $sovix__2=="$sovix__directory__sovix"."Public_sandbox.inc") {
    if (is_file($sovix__2) && $sovix__task=="visit-new-file") echo "File exist allready.";
    else {

    $sovix__script = $_POST['sovix__script']; $_SESSION['sovix__script']=$sovix__script;

					       if ($sovix__subtask=="writefile") {
						 /*  if (is_writable($sovix__2)) {  This is useless if we want to be able to insert a new file */
						 if($sovix__2&&$sovix__script) {
						   $sovix__foo=stripslashes($sovix__script);
						   $sovix__fp=fopen($sovix__2, "w+");
						   fwrite($sovix__fp,$sovix__foo);
						   fclose($sovix__fp);
						   echo "
<p>Wrote $sovix__2 &nbsp;
[ <a href=\"".str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2")."\">";
echo str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2");
echo "</a> ]
</p>";
						 }
					       }
      ?>
				  <form action="" method="post" />
				     <input type="hidden" name="sovix__input" value="open-file <?php echo $sovix__2 ?>" />
				     <input type="hidden" name="sovix__subtask" value="writefile" />
				     <textarea rows="30" name="sovix__script"><?php
				     if ($sovix__task=="open-file" && file_exists("$sovix__2")) echo htmlspecialchars(file_get_contents("$sovix__2"));
				     /*
                                       if (is_file($sovix__2)) {
					 $sovix__fp=fopen($sovix__2,"r");
					 $sovix__t="";
					 while(!feof($sovix__fp)) {
					   $sovix__t.=fread($sovix__fp,1024);
					 }
					 fclose($sovix__fp);
					 print htmlspecialchars($sovix__t);
				       }
                                     */
                                     ?></textarea>
					       <p></p>
					       <input type="submit" value="<?php
if ($sovix__task=="open-file" && file_exists("$sovix__2")) echo "Write  file";
elseif (!file_exists("$sovix__2")) echo "Insert file";
elseif ($sovix__task=="visit-new-file") echo "Insert file"; ?>" /><p></p>
					       Whitespace and line breaks may differ when writing to the<br />
					       file with one or 2 bytes so the MD5sum is likley to be changed even if no visible changes is being made..
					       </form>
					       <?php

    }
  }
  else echo "You are not logged in";
 }

elseif ($sovix__task=="extensions") {
  if (file_exists("$sovix__url__sovix/diet/")) echo "Sovix Diet is installed: [<a href=\"http://sovix.org/extensions/sovix-diet\">Find updates</a>]";
  else echo "No extensions is currently installed. <a href=\"http://sovix.org/extensions/\">Get more extensions</a>";
}

elseif ($sovix__task=="wikiinsert" && str_replace("$sovix__directory__document_root", "", dirname($sovix__2))=="/Main") {
  echo "<p><h2>wiki</h2>";

    if (!is_file($sovix__2)) echo "No such file. Begin with / to indicate DocumentRoot., press submit to write it.";
    if (is_file($sovix__2)) echo "File exist allready.";
    else {

    $sovix__script = $_POST['sovix__script']; $_SESSION['sovix__script']=$sovix__script;
      ?>
				  <form action="" method="post" />
				     <input type="hidden" name="sovix__input" value="open-file <?php echo $sovix__2 ?>" />
				     <input type="hidden" name="sovix__subtask" value="writefile" />
				     <textarea rows="30" name="sovix__script"></textarea>
					       <p></p>
					       <input type="submit" value="<?php if ($sovix__task=="wikiopen") echo "Modify file"; elseif ($sovix__task=="wikiinsert") echo "Insert file"; ?>" /><p></p>
					       Whitespace and line breaks may differ when writing to the<br />
					       file with one or 2 bytes so the MD5sum is likley to be changed.
					       </form>
					       <?php
					       if ($sovix__subtask=="writefile") {
						 if($sovix__2&&$sovix__script) {
						   $sovix__foo=htmlentities($sovix__script);
                                                   $sovix__zop="<?php \$sovix__directory__src=\$_SERVER\['DOCUMENT_ROOT'\].\"/sovix\"; \$sovix__directory__dotsovix=\"\$sovix__directory__src/../dotsovix/\"; require_once \"\$sovix__directory__src/header.inc\"; ?><pre>".$sovix__script."
</pre>

<?php require_once \"\$sovix__directory__src/footer.inc\"; ?>";
						   $sovix__fp=fopen($sovix__2, "w+");
						   fwrite($sovix__fp,$sovix__zop);
						   fclose($sovix__fp);
						   echo "
<p>Wrote $sovix__2 &nbsp;
[ <a href=\"".str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2")."\">";
echo str_replace("$sovix__directory__document_root", "http://".$_SERVER['SERVER_NAME'], "$sovix__2");
echo "</a> ]
</p>";
						 }
					       }

    }

}

elseif ($sovix__task=="html-entities") {

$sovix__i=1;
while ($sovix__i <= 8205):
  echo "&#"; echo "$sovix__i = &#38;&#35;$sovix__i&#59;"; echo "<br />\n";
$sovix__i++;
endwhile;
}

elseif ($sovix__task=="copy-file") {
  if ($_SESSION['sovix__user']=="root") {
    if (!copy("$sovix__2", "$sovix__3")) {
  echo "failed to copy $file...\n";
 }
    else echo "You are not logged in";
  }
}

elseif ($sovix__task=="read-file") {  ?>
  <?php
    if ($_SESSION['sovix__user']=="root" || ($sovix__file__read_file_ok==true || $sovix__allow_read_for_sovix_files==true)) {
      if (substr("$sovix__2", 0, 7)!="http://") {
	if (is_file($sovix__2)) highlight_file($sovix__2);
	else echo "No such file. Begin with / to indicate DocumentRoot.";
      }
      else echo "Define a file, not a URL. Begin with / to indicate DocumentRoot.";
    }
}
elseif ($sovix__task=="read-file-textarea") {
  if ($_SESSION['sovix__user']=="root" || ($sovix__file__read_file_ok==true || $sovix__allow_read_for_sovix_files==true)) {
    if (substr("$sovix__2", 0, 7)!="http://") {
      if (is_file($sovix__2)) {
	if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; }
  ?>
 <textarea rows="30" name="sovix__script"><?php
    if (is_file($sovix__2)) {
      echo htmlspecialchars(file_get_contents("$sovix__2"));
    }
   ?></textarea>
	<?php
	 }
      else echo "No such file. Begin with / to indicate DocumentRoot.";
    }
    elseif (substr("$sovix__2", 0, 7)=="http://")  {
      if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; } ?>
 <textarea rows="30" name="sovix__script"><?php
      echo htmlspecialchars(file_get_contents("$sovix__2"));
   ?></textarea>
	<?php
	}
  }
}
elseif ($sovix__task=="read-file-pre") {
  if ($_SESSION['sovix__user']=="root" || ($sovix__file__read_file_ok==true || $sovix__allow_read_for_sovix_files==true)) {
    if (substr("$sovix__2", 0, 7)!="http://") {
      if (is_file($sovix__2)) {
	if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; }
  ?>
 <pre><?php
    if (is_file($sovix__2)) {
      echo htmlspecialchars(file_get_contents("$sovix__2"));
    }
   ?></pre>
	<?php
	 }
      else echo "No such file. Begin with / to indicate DocumentRoot.";
    }
    elseif (substr("$sovix__2", 0, 7)=="http://")  {
      if (!isset($sovix__format)) { echo "<p><h2>Software code of: ".$sovix__2."</h2></p>"; } ?>
 <pre><?php
      echo htmlspecialchars(file_get_contents("$sovix__2"));
   ?></pre>
	<?php
	}
  }
}
elseif ($sovix__task=="read-pagesource") {

	 if (!is_file($sovix__2)) {
	   if (!isset($sovix__format)) { echo "<p><h2>Page source of: $sovix__2</h2></p>"; }
	   highlight_file($sovix__2);
	 }

}
elseif ($sovix__task=="file-get-contents") {
  if (isset($_SESSION['sovix__user'])) {
  if (substr("$sovix__2", 0, 7)!="http://") echo "Requested URL must begin with http://";
  else {
   echo "<p><h2>Getting contents from: ".$sovix__2."</h2></p>";
   echo file_get_contents("$sovix__2"); }
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="file-require") {
  if (isset($_SESSION['sovix__user'])) {
  if ($sovix__select_menu__index!="secret") {
    if (is_file($sovix__2)) {
   echo "<p><h2>Framing: ".$sovix__2."</h2></p>";
require_once $sovix__2;
    }
    else echo "No such file. Begin with / to indicate DocumentRoot..";
  }
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="delete-file") {
  if ($_SESSION['sovix__user']=="root") {
    if (is_file($sovix__2)) {unlink($sovix__2); echo "File $sovix__2 has been deleted.";}
    else "No such file. Begin with / to indicate DocumentRoot..";
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="make-directory") {
  if ($_SESSION['sovix__user']=="root") {
    mkdir($sovix__2); echo "Directory $sovix__2 has been made.";
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="delete-directory") {
  if ($_SESSION['sovix__user']=="root") {
    if(is_dir($sovix__2)) {rmdir($sovix__2); echo "Directory $sovix__2 has been deleted.";}
    else "No such directory.";
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="rename-file") {
  if ($_SESSION['sovix__user']=="root") {
  echo "$sovix__2 $sovix__3";
rename("$sovix__2", "$sovix__3");
  }
  else echo "You are not logged in";
}
elseif ($sovix__task=="identify") { ?>
 <?php
     if (file_exists($sovix__2)) { /* could be a directory so do not use if_file */
   echo "<p><h2>Identify: ".$sovix__2."</h2></p>";
       echo "
Filename: ".basename($sovix__2)."<br />
File path: ".dirname($sovix__2)."<br />
File extension: ". substr($sovix__2,strrpos($sovix__2,'.') + 0)."<br />
Number of lines: ".count(file("$sovix__2"))."<br />
md5 hash: ".md5_file($sovix__2)."<br />
Last access time of file: ".date ("Y-m-d H:i:s", fileatime($sovix__2))."<br />
Inode change time of file: ".date ("Y-m-d H:i:s", filectime($sovix__2))."<br />
File group: ".filegroup($sovix__2)."<br />
File inode: ".fileinode($sovix__2)."<br />
File modification time: ".date ("Y-m-d H:i:s", filemtime($sovix__2))."<br />
File owner: ".fileowner($sovix__2)."<br />
File permissions: ".fileperms($sovix__2)."<br />
File size: ".filesize($sovix__2)."<br />
File type: ".filetype($sovix__2)."<br />
";
     }
     else echo "No such file. Begin with / to indicate DocumentRoot..";
}
elseif (empty($sovix__task)) {
  echo "No command name given<p></p>";
}
else {
  echo "[No match]<p></p>";
}
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>
